@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2023 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2025 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -118,6 +118,7 @@ optDict = {
         "uCols": "string",
         "uChar": "string",
         "uFrom": "string",
+        "uValues": "string",
         "dnsDomain": "string",
         "secondUrl": "string",
         "secondReq": "string",
@@ -238,6 +239,8 @@ optDict = {
         "skipWaf": "boolean",
         "testFilter": "string",
         "testSkip": "string",
+        "timeLimit": "float",
+        "unsafeNaming": "boolean",
         "webRoot": "string",
     },
 
@@ -246,6 +249,7 @@ optDict = {
         "beep": "boolean",
         "dependencies": "boolean",
         "disableColoring": "boolean",
+        "disableHashing": "boolean",
         "listTampers": "boolean",
         "noLogging": "boolean",
         "offline": "boolean",
